@@ -24,12 +24,3 @@ proc objectWidgetName {class id {parentWidget .}} {
 proc llast {l} {
     return [lindex $l [expr [llength $l]-1]]
 }
-
-proc showWholeCanvas {canvas} {
-    set extent [$canvas bbox all]
-    set left [expr [lindex $extent 0]-1]
-    set top [expr [lindex $extent 1]-1]
-    set right [expr [lindex $extent 2]+1]
-    set bottom [expr [lindex $extent 3]+1]
-    $canvas configure -scrollregion [list $left $top $right $bottom] -width [expr $right-$left] -height [expr $bottom-$top]
-}
